'''
Author: shy
Description: 读写各种格式的文件，文件夹等等
LastEditTime: 2020-12-15 16:11:32
'''
import os, yaml
from pathlib import Path, PosixPath
from easydict import EasyDict as edict

def checkfolder(paths):
	""" paths type can be `str, PosixPath, or list`
	"""
	paths = paths if isinstance(paths, list) else [paths]
	
	def creat_dir(x):
		x = Path(x)
		if x.is_dir():
			print(f"Dir {x} already exists")
		else:
			Path.mkdir(x)
			print(f"Created new dir {x}")
	
	list(map(creat_dir, paths))

def read_yml(yml_file):
	with open(yml_file) as f:
		cfg = edict(yaml.safe_load(f))
	return cfg


'''
Author: shy
Description: 测试
LastEditTime: 2020-12-15 16:07:08
'''

import unittest
from pathlib import Path
from just_utils.io import checkfolder

class TestIO(unittest.TestCase):

	def test_single_path(self):
		path = "/mnt/shy/test_io/"
		checkfolder(path)
		self.assertTrue(Path(path).is_dir())
		path = Path("/mnt/shy/test_io/")
		checkfolder(path)
		self.assertTrue(Path(path).is_dir())

	def test_multi_path(self):
		paths = [   "/mnt/shy/test_io/1/",
					"/mnt/shy/test_io/2/",
					"/mnt/shy/test_io/3/", ]

		checkfolder(paths)
		for x in paths:
			self.assertTrue(Path(x).is_dir())


if __name__ == "__main__":
	unittest.main()


'''
Author: shy
Description: 
LastEditTime: 2020-12-15 16:12:21
'''
import setuptools

with open("README.md", "r") as fh:
	long_description = fh.read()

setuptools.setup(
	name="just_utils",
	version="0.1.2",
	author="Hansoluo",
	author_email="hansoluo757@gmail.com",
	description="A series of convenience functions to help training large image dataset with CNN",
	long_description=long_description,
	long_description_content_type="text/markdown",
	url="https://github.com/Hansoluo/cvutils.git",
	packages=['just_utils'],
	install_requires=['easydict', 'PyYAML'],
	python_requires='>=3.6',
	classifiers=(
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
	),
)